Crate oggopus_embedded

Crate oggopus_embedded 

Small no_std and no_alloc ogg parser for mono and stereo opus audio.

While this tries to follow the RFCs to the maximum extent reasonable, this is not suitable as general purpose ogg opus parser and you should never use this for untrusted inputs. This was built for parsing opus data from internal flash as part of an embedded system. You will want to use something else for anything more powerful than that.

See also RFC3533 and RFC7845.

Limitations

  • Supports only one logical stream at a time. Grouping is not supported.
  • Mixing (interleaving or otherwise) other types of streams than opus is not supported.
  • This parses ID header and ignores comment header.
  • This does not validate CRC or handle missing packets.
  • Seeking is not supported.
  • Parsing of RFC8486 family channel mappings is not supported.

Re-exports

pub use opus::ChannelMapping;
pub use states::Either;

Modules

opus
Opus parsing code.
prelude
oggopus_embedded prelude.
states
BitstreamReader states.

Structs

Bitstream
Ogg opus bitstream.
BitstreamReader
Reader for Bitstream.
Packet
Ogg packet.
Packets
Iterator for ogg packets.

Enums

BitstreamError
Error from parsing bitstream.
OggError
Error from parsing ogg container.

Type Aliases

EitherHeaderOrEnded
Header with reader for the stream or stream ended.
EitherPacketsOrEnded
Packets with reader for the stream or stream ended.
Result
Result of parsing bitstream.