#[non_exhaustive]pub enum ChannelMapping {
Family0 {
channels: u8,
},
Family1 {
channels: u8,
table: ChannelMappingTable<8>,
},
Family255 {
channels: u8,
table: ChannelMappingTable<255>,
},
Reserved {
channels: u8,
table: ChannelMappingTable<255>,
},
}Expand description
Channel mapping of opus stream.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Family0
Family 0 channel mapping.
Supports mono and stereo audio.
Family1
Family 1 channel mapping.
Vorbis channel order.
Fields

table: ChannelMappingTable<8>Channel mapping table.
Family255
Available on crate feature
family255 only.Family 255 channel mapping.
Channels are unidentified.
Reserved
Available on crate feature
family255 only.Reserved channel mapping value was used in the stream.
Such mapping may be a future extension to the container format.
Implementations
Sourceimpl ChannelMapping
impl ChannelMapping
Sourcepub fn get_channel_count(&self) -> u8
pub fn get_channel_count(&self) -> u8
Get channel count.
Sourcepub fn get_stream_count(&self) -> u8
pub fn get_stream_count(&self) -> u8
Get stream count.
Sourcepub fn get_coupled_stream_count(&self) -> u8
pub fn get_coupled_stream_count(&self) -> u8
Get coupled stream count.