pub enum DecodedChannel {
Mono,
Left,
Right,
}Expand description
Decoded opus channel to use for this audio channel.
Variants
Mono
The opus stream will be mono audio.
Left
Use the first decoded channel of the stereo stream.
Right
Use the second decoded channel of the stereo stream.