OpusHeader

Struct OpusHeader 

pub struct OpusHeader {
    pub version: u8,
    pub channels: ChannelMapping,
    pub pre_skip: u16,
    pub sample_rate: u32,
    pub output_gain: u16,
}
Opus header data.

Fields

version: u8

Opus version.

channels: ChannelMapping

Channel mapping.

pre_skip: u16

The number of samples to skip in the beginning of the stream.

sample_rate: u32

Sample rate used for the original audio.

output_gain: u16

Output gain.

Implementations

Source

impl OpusHeader

pub fn parse(input: &[u8]) -> Result<'_, Self>

Parse opus header from input data.

May return UnsupportedStream if family255 feature has not been enabled and such stream is encountered.