Packets

Struct Packets 

pub struct Packets<'data, const BUFFER_SIZE: usize> { /* private fields */ }
Iterator for ogg packets.

Note that this does not implement Iterator trait because it is not possible to borrow from iterator in Item.

Implementations

Source

impl<const BUFFER_SIZE: usize> Packets<'_, BUFFER_SIZE>

pub fn current_page_sequence_number(&self) -> u32

Returns page sequence number for the page being read.

pub fn last_page_sequence_number(&self) -> u32

Returns page sequence number of the last page.

pub fn bitstream_serial_number(&self) -> u32

Returns bitstream serial number for the page being read.

pub fn end_of_stream(&self) -> bool

Returns whether the current page is the end of the stream.

pub fn next(&mut self) -> Option<Packet<'_>>

Iterates to the next packet and returns it, or None if the last packet has been read.