pub type EitherHeaderOrEnded<'bs, 'data> = (Either<BitstreamReader<'bs, 'data, InStream>, BitstreamReader<'bs, 'data, EndOfStream>>, OpusHeader);Expand description
Header with reader for the stream or stream ended.
pub type EitherHeaderOrEnded<'bs, 'data> = (Either<BitstreamReader<'bs, 'data, InStream>, BitstreamReader<'bs, 'data, EndOfStream>>, OpusHeader);Header with reader for the stream or stream ended.