pub struct Packets<'data, const BUFFER_SIZE: usize> { /* private fields */ }Expand description
Implementations
Sourceimpl<const BUFFER_SIZE: usize> Packets<'_, BUFFER_SIZE>
impl<const BUFFER_SIZE: usize> Packets<'_, BUFFER_SIZE>
Sourcepub fn current_page_sequence_number(&self) -> u32
pub fn current_page_sequence_number(&self) -> u32
Returns page sequence number for the page being read.
Sourcepub fn last_page_sequence_number(&self) -> u32
pub fn last_page_sequence_number(&self) -> u32
Returns page sequence number of the last page.
Sourcepub fn bitstream_serial_number(&self) -> u32
pub fn bitstream_serial_number(&self) -> u32
Returns bitstream serial number for the page being read.
Sourcepub fn end_of_stream(&self) -> bool
pub fn end_of_stream(&self) -> bool
Returns whether the current page is the end of the stream.